@@ -6,10 +6,7 @@ use Text::Wrap;
 use Term::ANSIColor;
 use POSIX qw/floor ceil/;
 use List::Util qw/max min/;
-BEGIN {
-	eval { require Color::ANSI::Util; 1 }
-		and Color::ANSI::Util->import(qw/ansifg ansibg/);
-}
+use Color::ANSI::Util qw/ansifg ansibg/;
 
 extends 'Games::2048::Grid';
 
@@ -19,16 +16,14 @@ has needs_redraw => is => 'rw', default => 1;
 has win          => is => 'rw', default => 0;
 has lose         => is => 'rw', default => 0;
 
-use constant {
-	# dimensions
-	BORDER_WIDTH => 2,
-	BORDER_HEIGHT => 1,
+has moving     => is => 'rw';
+has moving_vec => is => 'rw';
 
-	CELL_WIDTH => 7,
-	CELL_HEIGHT => 3,
-
-	SCORE_WIDTH => 7,
-};
+has border_width  => is => 'rw', default => 2;
+has border_height => is => 'rw', default => 1;
+has cell_width    => is => 'rw', default => 7;
+has cell_height   => is => 'rw', default => 3;
+has score_width   => is => 'rw', default => 7;
 
 sub insert_tile {
 	my ($self, $cell, $value) = @_;
@@ -36,7 +31,7 @@ sub insert_tile {
 		value => $value,
 		appear => Games::2048::Animation->new(
 			duration => 0.2,
-			first_value => -1 / max(CELL_WIDTH, CELL_HEIGHT),
+			first_value => -1 / max($self->cell_width, $self->cell_height),
 			last_value => 1,
 		),
 	);
@@ -56,7 +51,7 @@ sub draw {
 	$self->draw_border_horizontal;
 
 	for my $y (0..$self->size-1) {
-		for my $line (0..CELL_HEIGHT-1) {
+		for my $line (0..$self->cell_height-1) {
 			$self->draw_border_vertical;
 
 			for my $x (0..$self->size-1) {
@@ -67,24 +62,24 @@ sub draw {
 				my $color = $self->tile_color($value);
 				my $bgcolor = $self->tile_color(undef);
 
-				my $lines = min(ceil(length($value // '') / CELL_WIDTH), CELL_HEIGHT);
-				my $first_line = floor((CELL_HEIGHT - $lines) / 2);
+				my $lines = min(ceil(length($value // '') / $self->cell_width), $self->cell_height);
+				my $first_line = floor(($self->cell_height - $lines) / 2);
 				my $this_line = $line - $first_line;
 
 				if ($this_line >= 0 and $this_line < $lines) {
-					my $cols = min(ceil(length($value) / $lines), CELL_WIDTH);
+					my $cols = min(ceil(length($value) / $lines), $self->cell_width);
 					my $string_offset = $this_line * $cols;
-					my $string_length = min($cols, length($value) - $string_offset, CELL_WIDTH);
-					my $cell_offset = floor((CELL_WIDTH - $string_length) / 2);
+					my $string_length = min($cols, length($value) - $string_offset, $self->cell_width);
+					my $cell_offset = floor(($self->cell_width - $string_length) / 2);
 
 					$string = " " x $cell_offset;
 
 					$string .= substr($value, $string_offset, $string_length);
 
-					$string .= " " x (CELL_WIDTH - $cell_offset - $string_length);
+					$string .= " " x ($self->cell_width - $cell_offset - $string_length);
 				}
 				else {
-					$string = " " x CELL_WIDTH;
+					$string = " " x $self->cell_width;
 				}
 
 				if ($tile and $tile->appear) {
@@ -92,16 +87,16 @@ sub draw {
 					$self->needs_redraw(1);
 
 					my $value = $tile->appear->value;
-					if ($line == CELL_HEIGHT-1) {
+					if ($line == $self->cell_height-1) {
 						$tile->appear(undef) if !$tile->appear->update;
 					}
 
-					my $x_center = (CELL_WIDTH  - 1) / 2;
-					my $y_center = (CELL_HEIGHT - 1) / 2;
+					my $x_center = ($self->cell_width  - 1) / 2;
+					my $y_center = ($self->cell_height - 1) / 2;
 
 					my $on = 0;
 					my $extra = 0;
-					for my $col (0..CELL_WIDTH-1) {
+					for my $col (0..$self->cell_width-1) {
 						my $x_distance = $col  / $x_center - 1;
 						my $y_distance = $line / $y_center - 1;
 						my $distance = $x_distance**2 + $y_distance**2;
@@ -157,7 +152,7 @@ sub draw_score {
 	my $best_score = "Best:";
 
 	my $blank_width = $self->board_width - length($score) - length($best_score);
-	my $score_width = min(floor(($blank_width - 1) / 2), SCORE_WIDTH);
+	my $score_width = min(floor(($blank_width - 1) / 2), $self->score_width);
 	my $inner_padding = $blank_width - $score_width * 2;
 
 	$self->draw_sub_score($score, $score_width, $self->score);
@@ -176,9 +171,7 @@ sub draw_sub_score {
 
 sub tile_color {
 	my ($self, $value) = @_;
-	state $use_color_util = $ENV{KONSOLE_DBUS_SERVICE}
-		&& exists &ansifg && exists &ansibg;
-    if ($use_color_util) {
+    if ($ENV{KONSOLE_DBUS_SERVICE}) {
         return
 		!defined $value    ? ansifg("BBADA0") . ansibg("CCC0B3")
 		: $value < 4       ? ansifg("776E65") . ansibg("EEE4DA")
@@ -195,7 +188,7 @@ sub tile_color {
 		                   : ansifg("F9F6F2") . ansibg("3C3A32") . color("bold");
 	}
 	my $bright = $^O eq "MSWin32" ? "underline " : "bright_";
-	my $bold = $^O eq "MSWin32" ? "underline" : "bold";
+	my $bold   = $^O eq "MSWin32" ? "underline"  : "bold";
 	return color (
 		!defined $value    ? "reset"
 		: $value < 4       ? "reverse cyan"
@@ -217,21 +210,21 @@ sub border_color {
 
 sub board_width {
 	my $self = shift;
-	return $self->size * CELL_WIDTH + BORDER_WIDTH * 2;
+	return $self->size * $self->cell_width + $self->border_width * 2;
 }
 
 sub board_height {
 	my $self = shift;
-	return $self->size * CELL_HEIGHT + BORDER_HEIGHT * 2;
+	return $self->size * $self->cell_height + $self->border_height * 2;
 }
 
 sub draw_border_horizontal {
 	my $self = shift;
-	say $self->border_color, " " x $self->board_width, color("reset") for 1..BORDER_HEIGHT;
+	say $self->border_color, " " x $self->board_width, color("reset") for 1..$self->border_height;
 }
 sub draw_border_vertical {
 	my $self = shift;
-	print $self->border_color, " " x BORDER_WIDTH, $self->tile_color(undef);
+	print $self->border_color, " " x $self->border_width, $self->tile_color(undef);
 }
 
 sub restore_cursor {
